#include <gst/player/player.h>
#include <gtk/gtk.h>

static GstPlayer *player;

static void on_volume_increase(GtkWidget *widget, gpointer data) {
    gdouble currentVolume = gst_player_get_volume(player);
    gst_player_set_volume(player, currentVolume + 0.1); // Increase volume by 10%
}

static void on_volume_decrease(GtkWidget *widget, gpointer data) {
    gdouble currentVolume = gst_player_get_volume(player);
    gst_player_set_volume(player, currentVolume - 0.1); // Decrease volume by 10%
}

static void activate(GtkApplication *app, gpointer user_data)
{
    GtkWidget *window;
    GtkWidget *increaseButton;
    GtkWidget *decreaseButton;

    window = gtk_application_window_new(app);
    gtk_window_set_application(GTK_WINDOW(window), GTK_APPLICATION(app));
    gtk_window_set_title(GTK_WINDOW(window), "Radio 45.0");
    gtk_window_set_default_size(GTK_WINDOW(window), 320, 240);

    increaseButton = gtk_button_new_with_label("Increase Volume");
    g_signal_connect(increaseButton, "clicked", G_CALLBACK(on_volume_increase), NULL);

    decreaseButton = gtk_button_new_with_label("Decrease Volume");
    g_signal_connect(decreaseButton, "clicked", G_CALLBACK(on_volume_decrease), NULL);

    GtkWidget *buttonBox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
    gtk_container_set_border_width(GTK_CONTAINER(buttonBox), 10);
    gtk_box_pack_start(GTK_BOX(buttonBox), increaseButton, FALSE, FALSE, 0);
    gtk_box_pack_start(GTK_BOX(buttonBox), decreaseButton, FALSE, FALSE, 0);

    GtkWidget *mainBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
    gtk_box_pack_start(GTK_BOX(mainBox), buttonBox, FALSE, FALSE, 0);

    player = gst_player_new(NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
    gst_player_set_uri(GST_PLAYER(player), "http://stream.live.vc.bbcmedia.co.uk/bbc_world_service");
    gst_player_play(GST_PLAYER(player));

    gtk_container_add(GTK_CONTAINER(window), mainBox);
    gtk_widget_show_all(window);
}

int main(int argc, char **argv)
{
    GtkApplication *app;
    int status;

    gst_init(&argc, &argv);

    app = gtk_application_new("org.gnome.Radio", G_APPLICATION_FLAGS_NONE);
    g_signal_connect(app, "activate", G_CALLBACK(activate), NULL);
    status = g_application_run(G_APPLICATION(app), argc, argv);
    g_object_unref(app);

    return status;
}
